Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorNathan Ridge2017-03-04 00:05:52 +0000
committerNathan Ridge2017-04-08 06:08:04 +0000
commitbe635f520a581a5341544265cfc496e134b5c5d9 (patch)
treeaf5f4eedab4555a07835046f34aba611397090b2
parente99970f5ae2968fe506ac4c67c95e2e7b7f6dc73 (diff)
downloadorg.eclipse.cdt-be635f520a581a5341544265cfc496e134b5c5d9.tar.gz
org.eclipse.cdt-be635f520a581a5341544265cfc496e134b5c5d9.tar.xz
org.eclipse.cdt-be635f520a581a5341544265cfc496e134b5c5d9.zip
Rename doKoenigLookup() to doArgumentDependentLookup()
"Koenig lookup" is an obscure term for argument-dependent lookup. We should use the standard terminology for ease of understanding. Change-Id: Ife59e03eaf3497aeca4a685e37250529732a78b6
-rw-r--r--core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/CPPSemantics.java6
-rw-r--r--core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/EvalFunctionSet.java8
2 files changed, 7 insertions, 7 deletions
diff --git a/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/CPPSemantics.java b/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/CPPSemantics.java
index f3892f091a4..1a37a1e4e1e 100644
--- a/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/CPPSemantics.java
+++ b/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/CPPSemantics.java
@@ -315,7 +315,7 @@ public class CPPSemantics {
// Perform argument dependent lookup
if (data.checkAssociatedScopes() && !data.hasTypeOrMemberFunctionOrVariableResult()) {
- doKoenigLookup(data);
+ doArgumentDependentLookup(data);
}
} catch (DOMException e) {
data.problem = (ProblemBinding) e.getProblem();
@@ -625,7 +625,7 @@ public class CPPSemantics {
return false;
}
- public static void doKoenigLookup(LookupData data) throws DOMException {
+ public static void doArgumentDependentLookup(LookupData data) throws DOMException {
data.ignoreUsingDirectives = true;
// Set 'qualified' to true for the duration of this function call so the calls to lookup()
// don't ascend into enclosing scopes.
@@ -3805,7 +3805,7 @@ public class CPPSemantics {
return null;
lookup(funcData, scope);
try {
- doKoenigLookup(funcData);
+ doArgumentDependentLookup(funcData);
} catch (DOMException e) {
}
diff --git a/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/EvalFunctionSet.java b/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/EvalFunctionSet.java
index 824e99a4274..b0448106ff6 100644
--- a/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/EvalFunctionSet.java
+++ b/core/org.eclipse.cdt.core/parser/org/eclipse/cdt/internal/core/dom/parser/cpp/semantics/EvalFunctionSet.java
@@ -311,7 +311,7 @@ public class EvalFunctionSet extends CPPDependentEvaluation {
try {
// Perform ADL if appropriate.
if (!fQualified && fImpliedObjectType == null && !data.hasTypeOrMemberFunctionOrVariableResult()) {
- CPPSemantics.doKoenigLookup(data);
+ CPPSemantics.doArgumentDependentLookup(data);
Object[] foundItems = (Object[]) data.foundItems;
if (foundItems != null && (functions == null || foundItems.length > functions.length)) {
@@ -327,12 +327,12 @@ public class EvalFunctionSet extends CPPDependentEvaluation {
}
}
// doKoenigLookup() may introduce duplicates into the result. These must be
// eliminated to avoid resolveFunction() reporting an ambiguity. (Normally, when
// lookup() and doKoenigLookup() are called on the same LookupData object, the
// two functions coordinate using data stored in that object to eliminate
// duplicates, but in this case lookup() was called before with a different
// LookupData object and now we are only calling doKoenigLookup()).
functions = ArrayUtil.removeDuplicates(functions);
}
}
@@ -327,12 +327,12 @@ public class EvalFunctionSet extends CPPDependentEvaluation {
}
}
- // doKoenigLookup() may introduce duplicates into the result. These must be
+ // doArgumentDependentLookup() may introduce duplicates into the result. These must be
// eliminated to avoid resolveFunction() reporting an ambiguity. (Normally, when
@@ -327,12 +327,12 @@ public class EvalFunctionSet extends CPPDependentEvaluation {
// eliminated to avoid resolveFunction() reporting an ambiguity. (Normally, when
- // lookup() and doKoenigLookup() are called on the same LookupData object, the
+ // lookup() and doArgumentDependentLookup() are called on the same LookupData object, the
// two functions coordinate using data stored in that object to eliminate
// duplicates, but in this case lookup() was called before with a different
@@ -327,12 +327,12 @@ public class EvalFunctionSet extends CPPDependentEvaluation {
// two functions coordinate using data stored in that object to eliminate
// duplicates, but in this case lookup() was called before with a different
- // LookupData object and now we are only calling doKoenigLookup()).
+ // LookupData object and now we are only calling doArgumentDependentLookup()).
functions = ArrayUtil.removeDuplicates(functions);
}

Back to the top